----
title:Teams & Projects
----
There are two ways to seperate things within Sentry. The first is a team. You can think of a team like an organization, and it's composed of many projects. You'll be able to add as many members to your team as you'd like (assuming you're on a paid account), and by default those members have access to all projects.

Projects generally separate different services or roles within your application. For example, a web app might have different projects for it's worker processes than it uses for its web processes. It might also split production and staging environments into different projects.
